@@ -17,7 +17,7 @@ import os
 import shutil
 import tarfile
 import tempfile
-from typing import List, Union
+from typing import List, Union, Optional
 from sagemaker import image_uris
 from sagemaker.inputs import TrainingInput
 from sagemaker.estimator import EstimatorBase
@@ -76,8 +76,7 @@ class _RepackModelStep(TrainingStep):
                     endpoints use this role to access training data and model
                     artifacts. After the endpoint is created, the inference code
                     might use the IAM role, if it needs to access an AWS resource.
-            model_data (str): The S3 location of a SageMaker model data
-                    ``.tar.gz`` file.
+            model_data (str): The S3 location of a SageMaker model data `.tar.gz` file.
             entry_point (str): Path (absolute or relative) to the local Python
                     source file which should be executed as the entry point to
                     inference. If ``source_dir`` is specified, then ``entry_point``
@@ -94,6 +93,8 @@ class _RepackModelStep(TrainingStep):
                         >>>         |----- test.py
 
                         You can assign entry_point='src/train.py'.
+            display_name (str): The display name of this `_RepackModelStep` step (default: None).
+            description (str): The description of this `_RepackModelStep` (default: None).
             source_dir (str): A relative location to a directory with other training
                 or model hosting source code dependencies aside from the entry point
                 file in the Git repo (default: None). Structure within this
@@ -124,12 +125,14 @@ class _RepackModelStep(TrainingStep):
 
                     This is not supported with "local code" in Local Mode.
             depends_on (List[str] or List[Step]): A list of step names or instances
-                    this step depends on
+                    this step depends on (default: None).
             retry_policies (List[RetryPolicy]): The list of retry policies for the current step
+                (default: None).
             subnets (list[str]): List of subnet ids. If not specified, the re-packing
-                    job will be created without VPC config.
+                    job will be created without VPC config (default: None).
             security_group_ids (list[str]): List of security group ids. If not
-                specified, the re-packing job will be created without VPC config.
+                specified, the re-packing job will be created without VPC config (default: None).
+            **kwargs: additional arguments for the repacking job.
         """
         self._model_data = model_data
         self.sagemaker_session = sagemaker_session
@@ -251,37 +254,16 @@ class _RepackModelStep(TrainingStep):
 
 
 class _RegisterModelStep(ConfigurableRetryStep):
-    """Register model step in workflow that creates a model package.
-
-    Attributes:
-        name (str): The name of the training step.
-        step_type (StepTypeEnum): The type of the step with value `StepTypeEnum.Training`.
-        estimator (EstimatorBase): A `sagemaker.estimator.EstimatorBase` instance.
-        model_data: the S3 URI to the model data from training.
-        content_types (list): The supported MIME types for the input data (default: None).
-        response_types (list): The supported MIME types for the output data (default: None).
-        inference_instances (list): A list of the instance types that are used to
-            generate inferences in real-time (default: None).
-        transform_instances (list): A list of the instance types on which a transformation
-            job can be run or on which an endpoint can be deployed (default: None).
-        model_package_group_name (str): Model Package Group name, exclusive to
-            `model_package_name`, using `model_package_group_name` makes the Model Package
-            versioned (default: None).
-        image_uri (str): The container image uri for Model Package, if not specified,
-            Estimator's training container image will be used (default: None).
-        compile_model_family (str): Instance family for compiled model, if specified, a compiled
-            model will be used (default: None).
-        container_def_list (list): A list of container definitions.
-        **kwargs: additional arguments to `create_model`.
-    """
+    """Register model step in workflow that creates a model package."""
 
     def __init__(
         self,
         name: str,
-        content_types,
-        response_types,
-        inference_instances,
-        transform_instances,
+        step_args: Optional[dict] = None,
+        content_types: Optional[list] = None,
+        response_types: Optional[list] = None,
+        inference_instances: Optional[list] = None,
+        transform_instances: Optional[list] = None,
         estimator: EstimatorBase = None,
         model_data=None,
         model_package_group_name=None,
@@ -292,8 +274,8 @@ class _RegisterModelStep(ConfigurableRetryStep):
         compile_model_family=None,
         display_name: str = None,
         description=None,
-        depends_on: Union[List[str], List[Step]] = None,
-        retry_policies: List[RetryPolicy] = None,
+        depends_on: Optional[Union[List[str], List[Step]]] = None,
+        retry_policies: Optional[List[RetryPolicy]] = None,
         tags=None,
         container_def_list=None,
         drift_check_baselines=None,
@@ -304,36 +286,38 @@ class _RegisterModelStep(ConfigurableRetryStep):
 
         Args:
             name (str): The name of the training step.
-            step_type (StepTypeEnum): The type of the step with value
-                `StepTypeEnum.Training`.
-            estimator (EstimatorBase): A `sagemaker.estimator.EstimatorBase` instance.
-            model_data: the S3 URI to the model data from training.
-            content_types (list): The supported MIME types for the
-                input data (default: None).
-            response_types (list): The supported MIME types for
-                the output data (default: None).
+            step_args (dict): The arguments for this `_RegisterModelStep` definition
+                (default: None).
+            content_types (list): The supported MIME types for the input data (default: None).
+            response_types (list): The supported MIME types for the output data (default: None).
             inference_instances (list): A list of the instance types that are used to
                 generate inferences in real-time (default: None).
             transform_instances (list): A list of the instance types on which a
                 transformation job can be run or on which an endpoint
                 can be deployed (default: None).
+            estimator (EstimatorBase): A `sagemaker.estimator.EstimatorBase` instance
+                (default: None).
+            model_data: the S3 URI to the model data from training (default: None).
             model_package_group_name (str): Model Package Group name, exclusive to
                 `model_package_name`, using `model_package_group_name`
                 makes the Model Package versioned (default: None).
             model_metrics (ModelMetrics): ModelMetrics object (default: None).
-            metadata_properties (MetadataProperties): MetadataProperties object
-                (default: None).
+            metadata_properties (MetadataProperties): MetadataProperties object (default: None).
             approval_status (str): Model Approval Status, values can be "Approved",
-                "Rejected", or "PendingManualApproval"
-                (default: "PendingManualApproval").
+                "Rejected", or "PendingManualApproval" (default: "PendingManualApproval").
             image_uri (str): The container image uri for Model Package, if not specified,
                 Estimator's training container image will be used (default: None).
             compile_model_family (str): Instance family for compiled model,
                 if specified, a compiled model will be used (default: None).
+            display_name (str): The display name of this `_RegisterModelStep` step (default: None).
             description (str): Model Package description (default: None).
             depends_on (List[str] or List[Step]): A list of step names or instances
-                this step depends on
+                this step depends on (default: None).
             retry_policies (List[RetryPolicy]): The list of retry policies for the current step
+                (default: None).
+            tags (List[dict[str, str]]): A list of dictionaries containing key-value pairs used to
+                configure the create model package request (default: None).
+            container_def_list (list): A list of container definitions (default: None).
             drift_check_baselines (DriftCheckBaselines): DriftCheckBaselines object (default: None).
             customer_metadata_properties (dict[str, str]): A dictionary of key-value paired
                 metadata properties (default: None).
@@ -342,6 +326,20 @@ class _RegisterModelStep(ConfigurableRetryStep):
         super(_RegisterModelStep, self).__init__(
             name, StepTypeEnum.REGISTER_MODEL, display_name, description, depends_on, retry_policies
         )
+        deprecated_args_missing = (
+            content_types is None
+            or response_types is None
+            or inference_instances is None
+            or transform_instances is None
+        )
+        if not (step_args is None) ^ deprecated_args_missing:
+            raise ValueError(
+                "step_args and the set of (content_types, response_types, "
+                "inference_instances, transform_instances) are mutually exclusive. "
+                "Either of them should be provided."
+            )
+
+        self.step_args = step_args
         self.estimator = estimator
         self.model_data = model_data
         self.content_types = content_types
@@ -369,67 +367,70 @@ class _RegisterModelStep(ConfigurableRetryStep):
         """The arguments dict that are used to call `create_model_package`."""
         model_name = self.name
 
-        if self.container_def_list is None:
-            if self.compile_model_family:
-                model = self.estimator._compiled_models[self.compile_model_family]
-                self.model_data = model.model_data
-            else:
-                # create_model wants the estimator to have a model_data attribute...
-                self.estimator._current_job_name = model_name
-
-                # placeholder. replaced with model_data later
-                output_path = self.estimator.output_path
-                self.estimator.output_path = "/tmp"
-
-                # create the model, but custom funky framework stuff going on in some places
-                if self.image_uri:
-                    model = self.estimator.create_model(image_uri=self.image_uri, **self.kwargs)
-                else:
-                    model = self.estimator.create_model(**self.kwargs)
-                    self.image_uri = model.image_uri
-
-                if self.model_data is None:
+        if self.step_args:
+            request_dict = self.step_args
+        else:
+            if self.container_def_list is None:
+                if self.compile_model_family:
+                    model = self.estimator._compiled_models[self.compile_model_family]
                     self.model_data = model.model_data
+                else:
+                    # create_model wants the estimator to have a model_data attribute...
+                    self.estimator._current_job_name = model_name
 
-                # reset placeholder
-                self.estimator.output_path = output_path
+                    # placeholder. replaced with model_data later
+                    output_path = self.estimator.output_path
+                    self.estimator.output_path = "/tmp"
 
-                # yeah, there is some framework stuff going on that we need to pull in here
-                if self.image_uri is None:
-                    region_name = self.estimator.sagemaker_session.boto_session.region_name
-                    self.image_uri = image_uris.retrieve(
-                        model._framework_name,
-                        region_name,
-                        version=model.framework_version,
-                        py_version=model.py_version if hasattr(model, "py_version") else None,
-                        instance_type=self.kwargs.get(
-                            "instance_type", self.estimator.instance_type
-                        ),
-                        accelerator_type=self.kwargs.get("accelerator_type"),
-                        image_scope="inference",
-                    )
-                    model.name = model_name
-                    model.model_data = self.model_data
+                    # create the model, but custom funky framework stuff going on in some places
+                    if self.image_uri:
+                        model = self.estimator.create_model(image_uri=self.image_uri, **self.kwargs)
+                    else:
+                        model = self.estimator.create_model(**self.kwargs)
+                        self.image_uri = model.image_uri
 
-        model_package_args = get_model_package_args(
-            content_types=self.content_types,
-            response_types=self.response_types,
-            inference_instances=self.inference_instances,
-            transform_instances=self.transform_instances,
-            model_package_group_name=self.model_package_group_name,
-            model_data=self.model_data,
-            image_uri=self.image_uri,
-            model_metrics=self.model_metrics,
-            drift_check_baselines=self.drift_check_baselines,
-            metadata_properties=self.metadata_properties,
-            approval_status=self.approval_status,
-            description=self.description,
-            tags=self.tags,
-            container_def_list=self.container_def_list,
-            customer_metadata_properties=self.customer_metadata_properties,
-        )
+                    if self.model_data is None:
+                        self.model_data = model.model_data
 
-        request_dict = get_create_model_package_request(**model_package_args)
+                    # reset placeholder
+                    self.estimator.output_path = output_path
+
+                    # yeah, there is some framework stuff going on that we need to pull in here
+                    if self.image_uri is None:
+                        region_name = self.estimator.sagemaker_session.boto_session.region_name
+                        self.image_uri = image_uris.retrieve(
+                            model._framework_name,
+                            region_name,
+                            version=model.framework_version,
+                            py_version=model.py_version if hasattr(model, "py_version") else None,
+                            instance_type=self.kwargs.get(
+                                "instance_type", self.estimator.instance_type
+                            ),
+                            accelerator_type=self.kwargs.get("accelerator_type"),
+                            image_scope="inference",
+                        )
+                        model.name = model_name
+                        model.model_data = self.model_data
+
+            model_package_args = get_model_package_args(
+                content_types=self.content_types,
+                response_types=self.response_types,
+                inference_instances=self.inference_instances,
+                transform_instances=self.transform_instances,
+                model_package_group_name=self.model_package_group_name,
+                model_data=self.model_data,
+                image_uri=self.image_uri,
+                model_metrics=self.model_metrics,
+                drift_check_baselines=self.drift_check_baselines,
+                metadata_properties=self.metadata_properties,
+                approval_status=self.approval_status,
+                description=self.description,
+                tags=self.tags,
+                container_def_list=self.container_def_list,
+                customer_metadata_properties=self.customer_metadata_properties,
+            )
+
+            request_dict = get_create_model_package_request(**model_package_args)
         # these are not available in the workflow service and will cause rejection
         if "CertifyForMarketplace" in request_dict:
             request_dict.pop("CertifyForMarketplace")
