@@ -14,12 +14,12 @@
 from __future__ import absolute_import
 
 from sagemaker.workflow.entities import (
-    Expression,
     RequestType,
+    PipelineVariable,
 )
 
 
-class ExecutionVariable(Expression):
+class ExecutionVariable(PipelineVariable):
     """Pipeline execution variables for workflow."""
 
     def __init__(self, name: str):
@@ -30,6 +30,13 @@ class ExecutionVariable(Expression):
         """
         self.name = name
 
+    def to_string(self) -> PipelineVariable:
+        """Prompt the pipeline to convert the pipeline variable to String in runtime
+
+        As ExecutionVariable is treated as String in runtime, no extra actions are needed.
+        """
+        return self
+
     @property
     def expr(self) -> RequestType:
         """The 'Get' expression dict for an `ExecutionVariable`."""
@@ -37,7 +44,15 @@ class ExecutionVariable(Expression):
 
 
 class ExecutionVariables:
-    """All available ExecutionVariable."""
+    """Provide access to all available execution variables:
+
+    - ExecutionVariables.START_DATETIME
+    - ExecutionVariables.CURRENT_DATETIME
+    - ExecutionVariables.PIPELINE_NAME
+    - ExecutionVariables.PIPELINE_ARN
+    - ExecutionVariables.PIPELINE_EXECUTION_ID
+    - ExecutionVariables.PIPELINE_EXECUTION_ARN
+    """
 
     START_DATETIME = ExecutionVariable("StartDateTime")
     CURRENT_DATETIME = ExecutionVariable("CurrentDateTime")
