@@ -13,10 +13,12 @@
 """The step definitions for workflow."""
 from __future__ import absolute_import
 
+import warnings
 from typing import List, Union
 
 import attr
 
+from sagemaker.deprecations import deprecated_class
 from sagemaker.estimator import EstimatorBase
 from sagemaker.model import Model
 from sagemaker import PipelineModel
@@ -50,7 +52,7 @@ class StepCollection:
         return [step.to_request() for step in self.steps]
 
 
-class RegisterModel(StepCollection):
+class RegisterModel(StepCollection):  # pragma: no cover
     """Register Model step collection for workflow."""
 
     def __init__(
@@ -242,6 +244,19 @@ class RegisterModel(StepCollection):
         steps.append(register_model_step)
         self.steps = steps
 
+        # TODO: add public document link here once ready
+        warnings.warn(
+            (
+                "We are deprecating the use of RegisterModel. "
+                "Instead, please use the ModelStep, which simply takes in the step arguments "
+                "generated by model.register()."
+            ),
+            DeprecationWarning,
+        )
+
+
+RegisterModel = deprecated_class(RegisterModel, "RegisterModel")
+
 
 class EstimatorTransformer(StepCollection):
     """Creates a Transformer step collection for workflow."""
